@@ -5,12 +5,14 @@
 #' 
 #' @param x [any]\cr
 #'   Argument.
-#' @param cl [\code{character(1)}]\cr
-#'   Class that argument must have. Checked with \code{is}.
+#' @param cl [\code{character}]\cr
+#'   Class that argument must \dQuote{inherit} from. 
+#'   If multiple classes are given, \code{x} must \dQuote{inherit} from at least one of these.
+#'   See also argument \code{s4}.
 #' @param s4 [\code{logical(1)}]\cr
-#'   If \code{TRUE}, use \code{is} for checking class \code{cl}, otherwise use \code{inherits}, which 
-#'   implies that onyl S3 classes are correctly checked. This is done for speed reasons
-#'   as calling \code{is} is pretty slow. 
+#'   If \code{TRUE}, use \code{is} for checking class \code{cl}, otherwise use \code{\link{inherits}}, which 
+#'   implies that only S3 classes are correctly checked. This is done for speed reasons
+#'   as calling \code{\link{is}} is pretty slow. 
 #'   Default is \code{FALSE}.
 #' @param len [\code{integer(1)}]\cr
 #'   Length that argument must have. 
@@ -75,19 +77,19 @@ checkArg = function(x, cl, s4=FALSE, len, min.len, max.len, choices, subset, low
     if (length(fs) < length(formals) || !all(formals == fs[seq_along(formals)]))
       stop("Argument function must have first formal args: ", paste(formals, collapse=","), "!")
   } else {
-    mycheck = 
-      if(identical(cl, "numeric"))
-        is.numeric
-      else if(identical(cl, "integer"))
-        is.integer
-      else if(identical(cl, "vector"))
-        is.vector
+    mycheck = function(x, cc)
+      if(identical(cc, "numeric"))
+        is.numeric(x)
+      else if(identical(cc, "integer"))
+        is.integer(x)
+      else if(identical(cc, "vector"))
+        is.vector(x)
       else if (!s4)
-        function(x) inherits(x, cl)
+        inherits(x, cc)
       else if (s4) 
-        function(x) is(x, cl)
-    if (!mycheck(x))
-      stop("Argument ", s, " must be of class ", cl, " not: ", cl2, "!")
+        is(x, cc)
+    if (!any(sapply(cl, mycheck, x=x)))
+      stop("Argument ", s, " must be of class ", collapse(cl, " OR "), ", not: ", cl2, "!")
     if (!missing(len) && len2 != len)
       stop("Argument ", s, " must be of length ", len, " not: ", len2, "!")
     if (!missing(min.len) && len2 < min.len)
