@@ -5,8 +5,9 @@
 #' @param seconds [\code{numeric(1)}]\cr
 #'   Number of seconds. If not an integer, it is rounded down.
 #' @param unit [\code{character(1)}]\cr
-#'   Largest unit to split seconds into. Must be one of the ones
-#'   listed in the function signature.
+#'   Largest unit to split seconds into. 
+#'   Must be one of: \code{c("years", "days", "hours", "minutes", "seconds")}.
+#'   Default is \dQuote{years}.
 #' @return [\code{numeric(5)}]. A named vector containing the
 #' \dQuote{years}, \dQuote{days}, \dQuote{hours}, \dQuote{minutes}
 #' and \dQuote{seconds}. Units larger than the given \code{unit} are
@@ -14,16 +15,17 @@
 #' @export
 #' @examples
 #' splitTime(1000)
-splitTime = function(seconds,
-                      unit=c("years", "days", "hours", "minutes", "seconds")) {
-  seconds = convertInteger(seconds)
-  unit = match.arg(unit)
+splitTime = function(seconds, unit="years") {
+	checkArg(seconds, "numeric", len=1L, na.ok=FALSE)
+	checkArg(unit, choices=c("years", "days", "hours", "minutes", "seconds"))
   divider = c(31536000L, 86400L, 3600L, 60L, 1L)
-  res = setNames(rep(NA_integer_, 5L), c("years", "days", "hours", "minutes", "seconds"))
+  res = setNames(rep(NA_integer_, 5L),
+                 c("years", "days", "hours", "minutes", "seconds"))
   start = which(names(res) == unit)
   for (i in start:length(divider)) {
     res[i] = seconds %/% divider[i]
     seconds = seconds - res[i] * divider[i]
   }
-  res
+  ## Make sure all values are integral and do _not_ strip names:  
+  sapply(res, as.integer)
 }
